# Prebuilt Images

Belows are prebuilt docker images, and their associated source dockerfiles. These prebuilt images might not be up-to-date. 
You may need to manually build them to get the latest functionalities of BytePS, using the source dockerfiles.   

| Docker Image Name | Source Dockerfile | Description |
| --- | --- | --- |
| bytepsimage/mxnet            | Dockerfile.mxnet            | Image for MXNet |
| bytepsimage/pytorch          | Dockerfile.pytorch          | Image for PyTorch |
| bytepsimage/tensorflow       | Dockerfile.tensorflow       | Image for TensorFlow |
